@@ -5,9 +5,9 @@ use IO::AIO;
 use Carp;
 use Time::HiRes qw(time);
 use Moo;
-extends "Archive::BagIt::Base";
+extends "Archive::BagIt";
 
-our $VERSION = '0.064'; # TRIAL VERSION
+our $VERSION = '0.073'; # TRIAL VERSION
 
 
 has 'digest_callback' => (
@@ -20,22 +20,31 @@ has 'digest_callback' => (
             my $filename =shift;
             my $opts = shift;
             my $MMAP_MIN = $opts->{mmap_min} || 8000000;
+            my $filesize = -s $filename;
             open(my $fh, "<:raw", "$filename") or croak ("Cannot open $filename, $!");
-            stat $fh;
-            $self->{stats}->{files}->{"$filename"}->{size}= -s _;
-            $self->{stats}->{size} += -s _;
+            $self->{stats}->{files}->{"$filename"}->{size}= $filesize;
+            $self->{stats}->{size} += $filesize;
             my $start_time = time();
             my $digest;
-            if (-s _ < $MMAP_MIN ) {
-                sysread $fh, my $data, -s _;
-                $digest = $digestobj->_digest->add($data)->hexdigest;
+            my $data;
+            if ($filesize < $MMAP_MIN ) {
+                sysread $fh, $data, $filesize;
+                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
+                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
+                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
+                delete $digestobj->{_digest};
+                $digest = unpack('H*', $result);
             }
-            elsif ( -s _ < 1500000000) {
-                IO::AIO::mmap my $data, -s _, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh or croak "mmap: $!";
-                $digest = $digestobj->_digest->add($data)->hexdigest;
+            elsif ( $filesize < 1500000000) {
+                IO::AIO::mmap $data, $filesize, IO::AIO::PROT_READ, IO::AIO::MAP_SHARED, $fh or croak "mmap: $!";
+                Net::SSLeay::EVP_DigestUpdate($digestobj->_digest, $data);
+                my $result = Net::SSLeay::EVP_DigestFinal($digestobj->_digest);
+                Net::SSLeay::EVP_MD_CTX_destroy($digestobj->_digest);
+                delete $digestobj->{_digest};
+                $digest = unpack('H*', $result);
             }
             else {
-                $digest = $digestobj->_digest->addfile($fh)->hexdigest;
+                $digest = $digestobj->get_hash_string($fh);
             }
             my $finish_time = time();
             $self->{stats}->{files}->{"$filename"}->{verify_time}= ($finish_time - $start_time);
@@ -61,7 +70,7 @@ Archive::BagIt::Fast
 
 =head1 VERSION
 
-version 0.064
+version 0.073
 
 =head1 NAME
 
@@ -100,7 +109,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
