@@ -2,10 +2,10 @@
 package Archive::BagIt::Plugin::Algorithm::MD5;
 use strict;
 use warnings;
-use Moo;
 use Carp;
+use Moo;
+use Net::SSLeay;
 use namespace::autoclean;
-
 with 'Archive::BagIt::Role::Algorithm';
 
 has '+plugin_name' => (
@@ -28,24 +28,23 @@ has '_digest' => (
 
 sub _build_digest_md5 {
     my ($self) = @_;
-    my $digest_md5 = Digest::MD5->new();
-    return $digest_md5;
+    my $md  = Net::SSLeay::EVP_get_digestbyname("md5");
+    my $digest = Net::SSLeay::EVP_MD_CTX_create();
+    Net::SSLeay::EVP_DigestInit($digest, $md);
+    return $digest;
 }
 
 sub get_hash_string {
     my ($self, $fh) = @_;
-    my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
-        $atime,$mtime,$ctime,$blksize,$blocks)
-        = stat $fh;
-    if ((!defined $blksize) || (length($blksize) < 1) || ($blksize <1)) {
-        $blksize = 8192;
-    }
+    my $blksize = $self->get_optimal_bufsize($fh);
     my $buffer;
     while (read($fh, $buffer, $blksize)) {
-        $self->_digest->add($buffer);
+        Net::SSLeay::EVP_DigestUpdate($self->_digest, $buffer);
     }
-    return $self->_digest->hexdigest;
-
+    my $result = Net::SSLeay::EVP_DigestFinal($self->_digest);
+    Net::SSLeay::EVP_MD_CTX_destroy($self->_digest);
+    delete $self->{_digest};
+    return unpack('H*', $result);
 }
 
 sub verify_file {
@@ -56,6 +55,7 @@ sub verify_file {
     close $fh || croak("could not close file '$filename', $!");
     return $digest;
 }
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -71,7 +71,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The MD5 algorithm plugin (default for v
 
 =head1 VERSION
 
-version 0.064
+version 0.073
 
 =head1 AVAILABILITY
 
@@ -90,7 +90,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
