@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Carp;
 use Moo;
+use Net::SSLeay;
 use namespace::autoclean;
 with 'Archive::BagIt::Role::Algorithm';
 
@@ -27,23 +28,23 @@ has '_digest' => (
 
 sub _build_digest_sha {
     my ($self) = @_;
-    my $digest = Digest::SHA->new("512");
+    my $md  = Net::SSLeay::EVP_get_digestbyname("sha512");
+    my $digest = Net::SSLeay::EVP_MD_CTX_create();
+    Net::SSLeay::EVP_DigestInit($digest, $md);
     return $digest;
 }
 
 sub get_hash_string {
     my ($self, $fh) = @_;
-    my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
-        $atime,$mtime,$ctime,$blksize,$blocks)
-        = stat $fh;
-    if ((!defined $blksize) || (length($blksize) < 1) || ($blksize <1)) {
-        $blksize = 8192;
-    }
+    my $blksize = $self->get_optimal_bufsize($fh);
     my $buffer;
     while (read($fh, $buffer, $blksize)) {
-        $self->_digest->add($buffer);
+        Net::SSLeay::EVP_DigestUpdate($self->_digest, $buffer);
     }
-    return $self->_digest->hexdigest;
+    my $result = Net::SSLeay::EVP_DigestFinal($self->_digest);
+    Net::SSLeay::EVP_MD_CTX_destroy($self->_digest);
+    delete $self->{_digest};
+    return unpack('H*', $result);
 }
 
 sub verify_file {
@@ -69,7 +70,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin (d
 
 =head1 VERSION
 
-version 0.064
+version 0.073
 
 =head1 AVAILABILITY
 
@@ -88,7 +89,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
