@@ -2,8 +2,6 @@
 package Archive::BagIt::Plugin::Manifest::MD5;
 use strict;
 use warnings;
-use Digest::MD5;
-use Sub::Quote;
 use Moo;
 with 'Archive::BagIt::Role::Manifest';
 
@@ -41,7 +39,6 @@ sub verify {
     return;
 }
 
-
 1;
 
 __END__
@@ -56,7 +53,7 @@ Archive::BagIt::Plugin::Manifest::MD5 - The role to load md5 plugin (default for
 
 =head1 VERSION
 
-version 0.064
+version 0.073
 
 =head1 AVAILABILITY
 
@@ -75,7 +72,7 @@ Rob Schmidt <rjeschmi@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
